@@ -84,11 +84,11 @@ def html_output(df, path_file_output):
     diff_report.write("<html>\n")
     diff_report.close()
 
-    css_file = open("Resources/table.css", 'r')
-    css = css_file.read()
-    css_file.close()
-    css_file = open(path_file_output + "table.css", 'w')
-    css_file.write(css)
+    #css_file = open("Resources/table.css", 'r')
+    #css = css_file.read()
+    #css_file.close()
+    #css_file = open(path_file_output + "table.css", 'w')
+    #css_file.write(css)
 
     iterreport = open(path_file_output + "diffReport.html", 'a')
     iterreport.write('<head>\n<style>\nbody{font:1.2em normal Arial,sans-serif;color:#34495E;}replace {'
